@@ -75,6 +75,10 @@ void empathy_irc_network_remove_server (EmpathyIrcNetwork *network,
 void empathy_irc_network_set_server_position (EmpathyIrcNetwork *network,
     EmpathyIrcServer *server, gint pos);
 
+const gchar * empathy_irc_network_get_name (EmpathyIrcNetwork *network);
+
+const gchar * empathy_irc_network_get_charset (EmpathyIrcNetwork *network);
+
 G_END_DECLS
 
 #endif /* __EMPATHY_IRC_NETWORK_H__ */
